Image Process Changelog
=======================

This Changelog is for ``minchin.pelican.plugins.summary``.

- :release:`1.1.0`
- :support:`-` first release to PyPI
- :support:`-` add release machinery
- :support:`-` move package to ``minchin.pelican.plugins.summary``
- :release:`1.0.0 <2017-01-29>`
- :support:`-` extract exising code from
  https://github.com/getpelican/pelican-plugins
